@@ -18,7 +18,7 @@ static const int ItemGridWidth = 158;
 
 static const int FrameThickness = 5;
 static const int ItemMargin = 2;
-class ItemsGridViewDelegate: public ItemsViewBaseDelegate
+class ItemsGridViewDelegate : public ItemsViewBaseDelegate
 {
     Q_OBJECT
 public:
@@ -32,9 +32,7 @@ public:
     QList<QWidget *> createItemWidgets(const QModelIndex &index) const override;
 
     // update the widgets
-    void updateItemWidgets(const QList<QWidget *> widgets,
-                                   const QStyleOptionViewItem &option,
-                                   const QPersistentModelIndex &index) const override;
+    void updateItemWidgets(const QList<QWidget *> widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const override;
 
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
